@@ -81,6 +81,9 @@ struct _GUPnPLinuxContextManagerPrivate {
          * structure */
         GHashTable *interfaces;
 
+        /* Receive buffer for netlink messages. */
+        char recvbuf[8196];
+
         gboolean dump_netlink_packets;
 };
 typedef struct _GUPnPLinuxContextManagerPrivate GUPnPLinuxContextManagerPrivate;
@@ -269,6 +272,7 @@ network_device_update_essid (NetworkInterface *device)
 static void
 network_device_create_context (NetworkInterface *device,
                                const char       *address,
+                               GSocketFamily     family,
                                const char       *label,
                                const char       *mask,
                                GInetAddressMask *host_mask)
@@ -276,6 +280,7 @@ network_device_create_context (NetworkInterface *device,
         guint port;
         GError *error = NULL;
         GUPnPContext *context;
+        GSSDPUDAVersion version;
 
         if (g_hash_table_contains (device->contexts, address)) {
                 g_debug ("Context for address %s on %s already exists",
@@ -285,7 +290,10 @@ network_device_create_context (NetworkInterface *device,
                 return;
         }
 
-        g_object_get (device->manager, "port", &port, NULL);
+        g_object_get (device->manager,
+                      "port", &port,
+                      "uda-version", &version,
+                      NULL);
 
         network_device_update_essid (device);
 
@@ -293,6 +301,8 @@ network_device_create_context (NetworkInterface *device,
                                   NULL,
                                   &error,
                                   "host-ip", address,
+                                  "address-family", family,
+                                  "uda-version", version,
                                   "interface", label,
                                   "network", device->essid ? device->essid
                                                            : mask,
@@ -558,6 +568,7 @@ create_context (GUPnPLinuxContextManager *self,
 
         network_device_create_context (device,
                                        address,
+                                       ifa->ifa_family,
                                        label,
                                        mask,
                                        host_mask);
@@ -777,20 +788,20 @@ remove_device (GUPnPLinuxContextManager *self,
 static void
 receive_netlink_message (GUPnPLinuxContextManager *self, GError **error)
 {
-        static char buf[8196];
-
         gssize len;
         GError *inner_error = NULL;
-        struct nlmsghdr *header = (struct nlmsghdr *) buf;
+        struct nlmsghdr *header;
         struct ifinfomsg *ifi;
         struct ifaddrmsg *ifa;
         GUPnPLinuxContextManagerPrivate *priv;
 
         priv = gupnp_linux_context_manager_get_instance_private (self);
 
+        header = (struct nlmsghdr *) priv->recvbuf;
+
         len = g_socket_receive (priv->netlink_socket,
-                                buf,
-                                sizeof (buf),
+                                priv->recvbuf,
+                                sizeof (priv->recvbuf),
                                 NULL,
                                 &inner_error);
         if (len == -1) {
@@ -807,7 +818,8 @@ receive_netlink_message (GUPnPLinuxContextManager *self, GError **error)
 
                 /* We should have at most len / 16 + 1 lines with 74 characters each */
                 hexdump = g_string_new_len (NULL, ((len / 16) + 1) * 73);
-                gupnp_linux_context_manager_hexdump ((guint8 *) buf, len, hexdump);
+                gupnp_linux_context_manager_hexdump ((guint8 *) priv->recvbuf,
+                                                     len, hexdump);
 
                 g_debug ("Netlink packet dump:\n%s", hexdump->str);
                 g_string_free (hexdump, TRUE);
